<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Режим полета включен</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Режим полета отключен</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Включить</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Режим полета</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Настройки режима полета</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Режим полета</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Мои устройства</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Настройки Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Выключено</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation>Если вы хотите подключиться к Bluetooth, сначала отключите [Режим полёта](#)</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Включить</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Настройки Bluetooth</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 подключен</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Подключение...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Выключен</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Подключен %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Не подключено</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Выкл.</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Яркость</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Настройки экрана</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Настройки экрана</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Яркость</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Вс</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Пн</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Вт</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Ср</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Чт</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Пт</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Сб</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Добавить раскладку клавиатуры</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Дата и время</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-часовой формат времени</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-часовой формат времени</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Настройки времени</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Открыть календарь</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Понедельник</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Вторник</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Среда</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Четверг</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Пятница</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Суббота</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Воскресенье</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>понедельник</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>вторник</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>среда</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>четверг</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>пятница</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>суббота</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>воскресенье</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Другие устройства</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>Режим DND</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Настройки режима DND</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Включить</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>Включен режим DND</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>Режим DND отключен</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>Режим DND</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Защита глаз</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Защита глаз включена </translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Защита глаз выключена</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Настройки экрана</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Защита глаз</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Вкл.</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Выкл.</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Светлая</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Темная</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Выключить защиту глаз</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Включить защиту глаз</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Настройки экрана</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Тема: Светлая</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Тема: Темная</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Тема: Авто</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Визуальный эффект</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Светлый</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Темный</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Авто</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Сообщений нет</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Настройки уведомлений</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Уведомления</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Выключить режим &quot;Не беспокоить&quot;</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Включить режим &quot;Не беспокоить&quot;</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Уведомление</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Экранная клавиатура</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Высокая производительность</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Сбалансированный</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Энергосбережение</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Сбалансированная производительность</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Питание</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Параметры питания</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>%1, осталось %2 мин.</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>%1, осталось %2 ч. %3 мин.</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Заряжается %1, %2 мин. до полной зарядки</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Заряжается %1, %2 ч. %3 мин. до полной зарядки</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>%1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Заряжается %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>%1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>%1, полностью заряжен</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>%1, не заряжается</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Батарея</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Зарядка, расчет времени до полной зарядки</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Расчет оставшегося времени использования</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>Осталось %1 мин.</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>Осталось %1 ч. %2 мин.</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Не заряжается</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Полностью заряжен</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Заряжается, %1 мин. до полной зарядки</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Заряжается, %1 ч. %2 мин. до полной зарядки</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>%1, осталось %2 ч.</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>Осталось %1 ч.</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Заряжается %1, %2 ч. до полной зарядки</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Заряжается, %1 ч. до полной зарядки</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Настройки питания</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Неизвестный</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Приостановить</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Спящий режим</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Блокировать</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Настройки питания</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Обновить и выключить</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Обновить и перезагрузить</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Сменить пользователя</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Сегодня</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Лунный</translation>
    </message>
    <message>
        <source>y</source>
        <translation>г</translation>
    </message>
    <message>
        <source>m</source>
        <translation>м</translation>
    </message>
    <message>
        <source>d</source>
        <translation>д</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Понедельник</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Вторник</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Среда</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Четверг</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Пятница</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Суббота</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Воскресенье</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Янв</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Фев</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Мар</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Апр</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Май</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Июн</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Июл</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Авг</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Сент</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Окт</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Ноя</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Дек</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Открыть календарь</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>понедельник</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>вторник</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>среда</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>четверг</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>пятница</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>суббота</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>воскресенье</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Громкость</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Вывод</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Настройки звука</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Включить звук</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Настройки звука</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Нет устройств вывода</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Громкость %1</translation>
    </message>
</context>
</TS>